"lmom.test.wak" <-
function(data) {
   lmom <- lmom.ub(data)
   para <- parwak(lmom)
   cat("WAKEBY DISTRIBUTION PARAMETERS\n")
   str(para)
   lmompara <- lmomwak(para)
   Q50 <- quawak(0.5,para)
   cat(c("Computed median=",Q50,"\n"),sep="")
   P50 <- cdfwak(Q50,para)
   cat(c("Nonexceedance of computed median=",P50,"\n"),sep="")
   lmom.diff(lmompara,lmom)
}

